Module driver

Module driver 

Structs

ProtocolCatalogEntry
Registry-facing catalog entry.
ProtocolDescriptor
Descriptor for a protocol driver registered with the runtime.
ProtocolDriverRegistry
Shared registry for protocol drivers.
ProtocolLaunchSpec
Generic launch request used by runtime sessions and the CLI.

Traits

ProtocolDriver
Compile-time extensibility point for protocol service creation.