pub struct ProtocolDriverRegistry { /* private fields */ }Expand description
Shared registry for protocol drivers.
Implementations
Sourceimpl ProtocolDriverRegistry
impl ProtocolDriverRegistry
Sourcepub fn register(&mut self, driver: impl ProtocolDriver + 'static)
pub fn register(&mut self, driver: impl ProtocolDriver + 'static)
Registers a driver by its descriptor key.
Sourcepub fn extend(&mut self, other: &Self)
pub fn extend(&mut self, other: &Self)
Extends the registry with all entries from another registry.
Sourcepub fn descriptors(&self) -> Vec<ProtocolDescriptor>
pub fn descriptors(&self) -> Vec<ProtocolDescriptor>
Returns the registered descriptors in stable order.
Sourcepub fn catalog(&self) -> Vec<ProtocolCatalogEntry>
pub fn catalog(&self) -> Vec<ProtocolCatalogEntry>
Returns catalog entries with driver features in stable order.