pub struct ProtocolLaunchSpec {
pub protocol: String,
pub name: Option<String>,
pub config: Value,
}Expand description
Generic launch request used by runtime sessions and the CLI.
Fields
protocol: StringStable protocol key matching a registered descriptor.
name: Option<String>Optional service name override.
config: ValueProtocol-specific configuration payload.
Implementations
Sourceimpl ProtocolLaunchSpec
impl ProtocolLaunchSpec
Sourcepub fn service_name(&self, descriptor: &ProtocolDescriptor) -> String
pub fn service_name(&self, descriptor: &ProtocolDescriptor) -> String
Returns the runtime service name using the descriptor as fallback.