pub struct RuntimeSessionSpec {
pub services: Vec<ProtocolLaunchSpec>,
pub readiness_timeout: Option<u64>,
}Expand description
Runtime session configuration shared by CLI controllers.
Fields
services: Vec<ProtocolLaunchSpec>Protocol services that should be launched in the session.
readiness_timeout: Option<u64>Optional readiness timeout override in milliseconds.
Implementations
Sourceimpl RuntimeSessionSpec
impl RuntimeSessionSpec
Sourcepub fn readiness_duration(&self, fallback: Duration) -> Duration
pub fn readiness_duration(&self, fallback: Duration) -> Duration
Returns the configured readiness timeout or a fallback duration.